(Rit Profile) เป็นตัวอย่างการอัพโหลด package ไปยัง pypi.org
===========================================================

PyPi: https://pypi.org/project/ritprofile/

สวัสดี แพ็กเกจนี้คือแพ็กเกจที่อธิบายโปรไฟล์ของคุณริด
สามารถนำไปใช้กับผู้อื่นได้

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install ritprofile

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   my = Profile('Loong')
   my.company = 'uncle-engineer'
   my.hobby = ['Youtuber','Reading','Sleeping']
   print(my.name)
   my.show_email()
   my.show_myart()
   my.show_hobby()

พัฒนาโดย: Super rit FB: https://www.facebook.com/UncleEngineer YouTube:
https://www.youtube.com/UncleEngineer
